#
# spec file for package python3-SQLAlchemy
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-SQLAlchemy
Version:        1.0.7
Release:        5.4
Url:            http://www.sqlalchemy.org
Summary:        Database Abstraction Library
License:        MIT
Group:          Development/Languages/Python
Source:         http://pypi.python.org/packages/source/S/SQLAlchemy/SQLAlchemy-%{version}.tar.gz
BuildRequires:  python3
BuildRequires:  python3-2to3
BuildRequires:  python3-devel
BuildRequires:  python3-nose
BuildRequires:  python3-setuptools

%description
SQLAlchemy is an Object Relational Mappper (ORM) that provides a flexible,
high-level interface to SQL databases.  Database and domain concepts are
decoupled, allowing both sides maximum flexibility and power. SQLAlchemy
provides a powerful mapping layer that can work as automatically or as manually
as you choose, determining relationships based on foreign keys or letting you
define the join conditions explicitly, to bridge the gap between database and
domain.

%package doc
Summary:        Documentation for python-SQLAlchemy
Group:          Documentation/Other
BuildArch:      noarch
Requires:       %{name} = %{version}

%description doc
This package contains HTML documentation, including tutorials and API
reference for python-SQLAlchemy.

%prep
%setup -q -n SQLAlchemy-%{version}
rm -rf doc/build # Remove unnecessary scripts for building documentation

%build
find examples -name *.bak -exec rm -f {} \;
# Currently the cextension doesn't work with py3
CFLAGS="%{optflags} -fno-strict-aliasing" python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

# Tests fail for all versions
#%check
#python3 ./sqla_nose.py

%files
%defattr(-,root,root,-)
%doc CHANGES LICENSE README.dialects.rst README.rst README.unittests.rst
%{python3_sitearch}/sqlalchemy/
%{python3_sitearch}/SQLAlchemy-%{version}-py%{py3_ver}.egg-info

%files doc
%defattr(-,root,root)
%doc doc examples

%changelog
* Tue Jul 21 2015 arun@gmx.de
- update to version 1.0.7:
  * see http://docs.sqlalchemy.org/en/latest/changelog/changelog_10.html#change-1.0.7
* Mon Jul 13 2015 arun@gmx.de
- update to version 1.0.6:
  * see http://docs.sqlalchemy.org/en/latest/changelog/changelog_10.html#change-1.0.6
* Sat Jun 13 2015 arun@gmx.de
- update to version 1.0.5:
  * see http://docs.sqlalchemy.org/en/latest/changelog/changelog_10.html#change-1.0.5
* Sat May  9 2015 arun@gmx.de
- update to version 1.0.4:
  * see http://docs.sqlalchemy.org/en/latest/changelog/changelog_10.html#change-1.0.4
* Sat May  2 2015 arun@gmx.de
- update to version 1.0.3:
  * see http://docs.sqlalchemy.org/en/latest/changelog/changelog_10.html#change-1.0.3
* Sat Apr 25 2015 arun@gmx.de
- update to version 1.0.2:
  * see http://docs.sqlalchemy.org/en/latest/changelog/changelog_10.html#change-1.0.2
* Fri Apr 24 2015 arun@gmx.de
- update to version 1.0.1:
  see http://docs.sqlalchemy.org/en/latest/changelog/changelog_10.html#change-1.0.1
  for detailed list of changes
* Sun Apr 19 2015 arun@gmx.de
- update to version 1.0.0:
  * long list of changes, see http://docs.sqlalchemy.org/en/latest/changelog/changelog_10.html#change-1.0.0
* Wed Mar 11 2015 arun@gmx.de
- update to version 0.9.9:
  * long changelog, see
    http://docs.sqlalchemy.org/en/latest/changelog/changelog_09.html
    for details
* Sat Jan 17 2015 arun@gmx.de
- specfile:
  * update copyright year
  * Drop SQLAlchemy-import-logging-handlers.patch:
    + test_mapper.py got fixed upstream
    + test_execute.py doesn't use logging anymore
  * no more README.py3k. removed it from spec file
  * remove noarch
  * changed sitelib to sitearch in %%files section
  * removed some 2to3 conversion that is not needed anymore
- update to version 0.9.8:
  Many changes (a few thousand lines), see links below for complete list
  http://docs.sqlalchemy.org/en/latest/changelog/changelog_09.html
  http://docs.sqlalchemy.org/en/latest/changelog/changelog_08.html
* Fri Nov  1 2013 p.drouand@gmail.com
- Update to version 0.8.3
  + See http://docs.sqlalchemy.org/en/latest/changelog/changelog_08.html#change-0.8.3
- Fix build on Factory
* Sat Oct 26 2013 p.drouand@gmail.com
- Update to version 0.8.2
  + Too numuch changes
    See http://docs.sqlalchemy.org/en/latest/changelog/changelog_08.html#change-0.8.2
- Don't apply SQLAlchemy-import-logging-handlers.patch; sounds fixed
  by upstream
* Thu Jul 18 2013 speilicke@suse.com
- Add SQLAlchemy-import-logging-handlers.patch: Fix missing imports
  during test runs
* Tue Jul 16 2013 speilicke@suse.com
- Run 2to3
* Fri Mar  8 2013 lars@linux-schulserver.de
- update to 0.7.10:
  * orm
  + [bug] Fixed Session accounting bug whereby replacing
    a deleted object in the identity map with another
    object of the same primary key would raise a
    "conflicting state" error on rollback(),
    if the replaced primary key were established either
    via non-unitofwork-established INSERT statement
    or by primary key switch of another instance.
    [ticket:2583]
  * oracle
  + [bug] changed the list of cx_oracle types that are
    excluded from the setinputsizes() step to only include
    STRING and UNICODE; CLOB and NCLOB are removed.  This
    is to work around cx_oracle behavior which is broken
    for the executemany() call.  In 0.8, this same change
    is applied however it is also configurable via the
    exclude_setinputsizes argument. [ticket:2561]
  * mysql
  + [feature] Added "raise_on_warnings" flag to OurSQL
    dialect.  [ticket:2523]
  + [feature] Added "read_timeout" flag to MySQLdb
    dialect.  [ticket:2554]
* Wed Dec 19 2012 saschpe@suse.de
- The doc package is noarch
* Thu Nov 22 2012 toddrme2178@gmail.com
- Remove openSUSE 11.4 spec file workarounds
* Fri May 25 2012 toddrme2178@gmail.com
- Fix building on openSUSE 11.4
- spec file cleanups
* Wed May 23 2012 highwaystar.ru@gmail.com
- python3-SQLAlchemy package added
